Instruction.push_back("CMA");
Instruction.push_back("CMC");
Instruction.push_back("CMP");
Instruction.push_back("CNC");
Instruction.push_back("CNZ");
Instruction.push_back("CP");
Instruction.push_back("CPO");
Instruction.push_back("CZ");
Instruction.push_back("CPI");
Instruction.push_back("CPE");

Parameters("CPO")=1;
Parameters("CZ")=1;
Parameters("CPI")=1;
Parameters("CPE")=1;
Parameters("CP")=1;
Parameters("CNZ")=1;
Parameters("CNC")=1;
Parameters("CMP")=1;
Parameters("CMC")=0;
Parameters("CMA")=0;

// The contents of the accumulator are complemented. No flags are affected.
void CMC()
{
    Register[IndexOfRegister["A"]]=~Register[IndexOfRegister["A"]];
    Update();
}

//The Carry flag is complemented. No other flags are affected.
void CMA()
{
    Flag[IndexOfFlag["CY"]]=~Flag[IndexOfFlag["CY"]];
    Update();
}

/*
The contents of the operand (register or memory) are
compared with the contents of the accumulator. Both
contents are preserved . The result of the comparison is
shown by setting the flags of the PSW as follows:
if (A) < (reg): carry flag is set
if (A) = (reg): zero flag is set
if (A) > (reg): carry and zero flags are reset
*/
void CMP(string a)
{
    if(Register[IndexOfRegister["A"]]<Register[IndexOfRegister[a]])
        Flag[IndexOfFlag["CY"]=1;
    else if(Register[IndexOfRegister["A"]]=Register[IndexOfRegister[a]])
        Flag[IndexOfFlag["Z"]=1;
    else
    {
        Flag[IndexOfFlag["CY"]=0;
        Flag[IndexOfFlag["Z"]=0;
    }
    update();
}

/*The program sequence is transferred to the memory location
specified by the 16-bit address given in the operand  if carry flag is set to 0   */
void CNC(int a)
{
    if (Flag[IndexOfFlag["CY"]]==0)
        CALL(a);
    update();
}

/*The program sequence is transferred to the memory location
specified by the 16-bit address given in the operand  if zero flag is set to 0   */
void CNZ(int a)
{
    if (Flag[IndexOfFlag["Z"]]==0)
        CALL(a);
    update();
}


/*The program sequence is transferred to the memory location
specified by the 16-bit address given in the operand  if sign flag is set to 0   */
void CP(int a)
{
    if (Flag[IndexOfFlag["S"]]==0)
        CALL(a);
    update();
}

/*The program sequence is transferred to the memory location
specified by the 16-bit address given in the operand  if parity flag is set to 1   */
void CPE(int a)
{
    if (Flag[IndexOfFlag["P"]]==1)
        CALL(a);
    update();
}

/*
The second byte (8-bit data) is compared with the contents of
the accumulator. The values being compared remain
unchanged. The result of the comparison is shown by setting
the flags of the PSW as follows:
if (A) < data: carry flag is set
if (A) = data: zero flag is set
if (A) > data: carry and zero flags are reset
*/
void CPI(int a)
{
    if(Register[IndexOfRegister["A"]]<a)
        Flag[IndexOfFlag["CY"]=1;
    else if(Register[IndexOfRegister["A"]]=a)
        Flag[IndexOfFlag["Z"]=1;
    else
    {
        Flag[IndexOfFlag["CY"]=0;
        Flag[IndexOfFlag["Z"]=0;
    }
    update();
}


/*The program sequence is transferred to the memory location
specified by the 16-bit address given in the operand  if parity flag is set to 0  */
void CPO(int a)
{
    if (Flag[IndexOfFlag["P"]]==0)
        CALL(a);
    update();
}

/*The program sequence is transferred to the memory location
specified by the 16-bit address given in the operand  if zero flag is set to 1  */
void CZ(int a)
{
    if (Flag[IndexOfFlag["Z"]]==1)
        CALL(a);
    update();
}
